"use client";
import { verifyPayment } from "@/servers/actions/checkout-action";
import { useCart } from "@/servers/data/use-cart";
import { Icon } from "@iconify/react/dist/iconify.js";
import { Loader2 } from "lucide-react";
import { useTranslations } from "next-intl";
import { useRouter, useSearchParams } from "next/navigation";
import React, { useEffect, useState, useTransition } from "react";
import { toast } from "sonner";
import InvoiceDetails from "./invoice-details";

const OrderStatus: React.FC = () => {
	const router = useRouter();
	const t = useTranslations("Cart");
	const searchParams = useSearchParams();
	const { cart } = useCart();
	console.log("cart: ", cart);
	const [orderInfo, setOrderInfo] = useState({
		id: 0,
		status: "",
		first_name: "",
		middle_name: "",
		last_name: "",
		email: "",
		phone: "",
		address: "",
		payment_status: "",
		city: { name: "" },
		area: { name: "" },
		location_lat: "",
		location_lng: "",
		additional_description: "",
		delivery_price: 0,
		total_price: 0,
		subtotal: 0,
		vat_value: 0,
	});
	const [isPending, startTransition] = useTransition();
	const [payload, setPayload] = useState({});

	useEffect(() => {
		// Get values from URL parameters
		const status = searchParams.get("status") ?? "";
		const order_id = searchParams.get("UserField1");
		const responseHash = searchParams.get("responseHash");
		const tranId = searchParams.get("TranId");
		const responseCode = searchParams.get("ResponseCode");
		const amount = searchParams.get("amount");
		const trackId = searchParams.get("TrackId");
		console.log("order_id: ", order_id);

		if (order_id && responseHash && tranId && responseCode && amount && trackId) {
			const _payload = {
				order_id,
				responseHash,
				TranId: tranId,
				ResponseCode: responseCode,
				amount,
				TrackId: trackId
			};
			setPayload(_payload);
		}

		if (cart?.length === 0 && status !== "restore" && status !== "pay") {
			router.push("/user-account" as any);
		}
	}, [searchParams, cart]);

	console.log("payload: ", payload);
	const submit = async () => {
		startTransition(async () => {
			try {

				const result = await verifyPayment(payload);
				console.log("result: ", result);
				if (result?.success) {
					toast.success(t("Payment verified successfully"), {
						style: { backgroundColor: "green", color: "white" },
					});
					setOrderInfo({
						...result?.order,
						id: Number(result?.order?.id),
						total_price: parseFloat(result?.order?.grand_total) + parseFloat(result?.order?.delivery_price),
					});

				} else {
					toast.error(t(result?.message?.replace(".", "")));
					if (result?.status === 401) router.push("/login");
				}
			} catch (error) {
				console.error("Error submitting form: ", error);
				toast.error("حدث خطأ أثناء التوصيل");
			}
		});
	};
	console.log("orderInfo: ", orderInfo);

	return (
		<div className="flex flex-col gap-4">
			<h1 className="mb-2 text-xl text-start leading-7 text-custom-primary-accent md:mb-4 md:text-[32px] md:leading-[76px]">{t("ConfirmOrder")}</h1>
			<div className="max-w-2xl w-[700px] mx-auto p-6 bg-white rounded-lg shadow-sm">

				{!orderInfo?.id ?
					<div className="flex gap-4 mb-8">
						<button className="flex items-center justify-center gap-2 bg-custom-primary-accent text-white px-6 py-3 rounded-lg flex-1"
							disabled={isPending} onClick={submit}>
							{isPending && <Loader2 className="w-4 h-4 ml-2 animate-spin" />}
							<span>{t("Confirm")}</span>
						</button>
					</div>

					:
					(
						<>
							{/* Success Message */}
							<div className="text-right mb-8">
								<div className="flex justify-start items-center gap-4 mb-4">
									<h1 className="text-2xl font-bold text-green-600 mb-4">تم تنفيذ الطلب بنجاح</h1>
									<Icon icon="lets-icons:check-fill" className="text-green-600 text-5xl -mt-2" />
								</div>
							</div>


							<InvoiceDetails orderInfo={orderInfo} />

							<div className="flex justify-between">
								<button className="bg-custom-primary-accent text-white px-6 py-3 rounded-lg flex-1"
									onClick={() => router.push("/user-account")}>
									<span>عرض الطلبات</span>
								</button>
							</div>
						</>
					)
				}
			</div>
		</div>
	);
};

export default OrderStatus;
